@@ -12,13 +12,13 @@
  * @author Akinobu Lee
  * @date   Thu May 12 14:14:01 2005
  *
- * $Revision: 1.15 $
+ * $Revision: 1.20 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -740,7 +740,15 @@ print_engine_info(Recog *recog)
     } else {
       jlog("off, returns search failure\n");
     }
-
+#ifdef USE_MBR
+    if (r->config->mbr.use_mbr) {
+      jlog("\n");
+      jlog("Minimum Bayes Risk Decoding:\n");
+      jlog("\t(-mbr)        sentence rescoring on MBR = %s\n", r->config->mbr.use_mbr ? "yes" : "no");
+      jlog("\t(-mbr_wwer)   use word weight on MBR = %s\n", r->config->mbr.use_word_weight ? "yes" : "no");
+      jlog("\t(-mbr_weight) score weight = %2.1f  loss func. weight  = %2.1f\n", r->config->mbr.score_weight, r->config->mbr.loss_weight);
+    }
+#endif
     jlog("\n");
   }
 
@@ -893,6 +901,12 @@ print_engine_info(Recog *recog)
     } else {
       jlog("\t    long-term DC removal = off\n");
     }
+    jlog("\t    long-term DC removal = off\n");
+    if (jconf->preprocess.level_coef != 1.0) {
+      jlog("\t    level scaling factor = %.2f\n", jconf->preprocess.level_coef);
+    } else {
+      jlog("\t    level scaling factor = %.2f (disabled)\n", jconf->preprocess.level_coef);
+    }
   }
   jlog("\t      reject short input = ");
   if (jconf->reject.rejectshortlen > 0) {
@@ -900,6 +914,12 @@ print_engine_info(Recog *recog)
   } else {
     jlog("off\n");
   }
+  jlog("\t      reject  long input = ");
+  if (jconf->reject.rejectlonglen >= 0) {
+    jlog("longer than %d msec\n", jconf->reject.rejectlonglen);
+  } else {
+    jlog("off\n");
+  }
 #ifdef POWER_REJECT
   jlog("\t   power rejection thres = %f", jconf->reject.powerthres);
 #endif
