@@ -18,13 +18,13 @@
  * @author Akinobu Lee
  * @date   Thu May 12 18:52:07 2005
  *
- * $Revision: 1.26 $
+ * $Revision: 1.31 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -423,6 +423,11 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       GET_TMPARG;
       jconf->reject.rejectshortlen = atoi(tmparg);
       continue;
+    } else if (strmatch(argv[i],"-rejectlong")) { /* long input rejection */
+      if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE; 
+      GET_TMPARG;
+      jconf->reject.rejectlonglen = atoi(tmparg);
+      continue;
 #ifdef POWER_REJECT
     } else if (strmatch(argv[i],"-powerthres")) { /* short input rejection */
       if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE; 
@@ -979,6 +984,11 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE; 
       jconf->preprocess.use_zmean = FALSE;
       continue;
+    } else if (strmatch(argv[i],"-lvscale")) { /* input level scaling factor */
+      if (!check_section(jconf, argv[i], JCONF_OPT_GLOBAL)) return FALSE; 
+      GET_TMPARG;
+      jconf->preprocess.level_coef = (float)atof(tmparg);
+      continue;
     } else if (strmatch(argv[i],"-zmeanframe")) { /* enable frame-wise DC offset by zero mean */
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
       jconf->amnow->analysis.para.zmeanframe = TRUE;
@@ -1362,6 +1372,43 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
 	//return FALSE;
 	unknown_opt = TRUE;
       }
+
+#ifdef USE_MBR
+    } else if (strmatch(argv[i],"-mbr")) {
+
+      if (!check_section(jconf, argv[i], JCONF_OPT_SR)) return FALSE;
+      jconf->searchnow->mbr.use_mbr = TRUE;
+      jconf->searchnow->mbr.use_word_weight = FALSE;
+
+      continue;
+
+    } else if (strmatch(argv[i],"-mbr_wwer")) {
+
+      if (!check_section(jconf, argv[i], JCONF_OPT_SR)) return FALSE;
+      jconf->searchnow->mbr.use_mbr = TRUE;
+      jconf->searchnow->mbr.use_word_weight = TRUE;
+
+      continue;
+
+    } else if (strmatch(argv[i],"-nombr")) {
+
+      if (!check_section(jconf, argv[i], JCONF_OPT_SR)) return FALSE;
+      jconf->searchnow->mbr.use_mbr = FALSE;
+      jconf->searchnow->mbr.use_word_weight = FALSE;
+
+      continue;
+
+    } else if (strmatch(argv[i],"-mbr_weight")) {
+
+      if (!check_section(jconf, argv[i], JCONF_OPT_SR)) return FALSE;
+      GET_TMPARG;
+      jconf->searchnow->mbr.score_weight = (LOGPROB)atof(tmparg);
+      GET_TMPARG;
+      jconf->searchnow->mbr.loss_weight = (LOGPROB)atof(tmparg);
+
+      continue;
+#endif
+
     } else {			/* error */
       //jlog("ERROR: m_options: wrong argument: %s\n", argv[0], argv[i]);
       //return FALSE;
