@@ -12,13 +12,13 @@
  * @author Akinobu Lee
  * @date   Fri May 13 15:04:34 2005
  *
- * $Revision: 1.17 $
+ * $Revision: 1.23 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -111,9 +111,11 @@ j_output_argument_help(FILE *fp)
   fprintf(fp, "    [-adport portnum]   adinnet port number to listen         (%d)\n", jconf->input.adinnet_port);
   fprintf(fp, "    [-48]               enable 48kHz sampling with internal down sampler (OFF)\n");
   fprintf(fp, "    [-zmean/-nozmean]   enable/disable DC offset removal      (OFF)\n");
+  fprintf(fp, "    [-lvscale]          input level scaling factor (1.0: OFF) (%.1f)\n", jconf->preprocess.level_coef);
   fprintf(fp, "    [-nostrip]          disable stripping off zero samples\n");
   fprintf(fp, "    [-record dir]       record triggered speech data to dir\n");
   fprintf(fp, "    [-rejectshort msec] reject an input shorter than specified\n");
+  fprintf(fp, "    [-rejectlong msec]  reject an input longer than specified\n");
 #ifdef POWER_REJECT
   fprintf(fp, "    [-powerthres value] rejection threshold of average power  (%.1f)\n", jconf->reject.powerthres);
 #endif
@@ -167,8 +169,8 @@ j_output_argument_help(FILE *fp)
 
   fprintf(fp, "\n Acoustic analysis:\n");
   fprintf(fp, "    [-htkconf file]     load parameters from the HTK Config file\n");
-  fprintf(fp, "    [-smpFreq freq]     sample period (Hz)                    (%ld)\n", jconf->am_root->analysis.para_default.smp_freq);
-  fprintf(fp, "    [-smpPeriod period] sample period (100ns)                 (%ld)\n", jconf->am_root->analysis.para_default.smp_period);
+  fprintf(fp, "    [-smpFreq freq]     sample period (Hz)                    (%d)\n", jconf->am_root->analysis.para_default.smp_freq);
+  fprintf(fp, "    [-smpPeriod period] sample period (100ns)                 (%d)\n", jconf->am_root->analysis.para_default.smp_period);
   fprintf(fp, "    [-fsize sample]     window size (sample)                  (%d)\n", jconf->am_root->analysis.para_default.framesize);
   fprintf(fp, "    [-fshift sample]    frame shift (sample)                  (%d)\n", jconf->am_root->analysis.para_default.frameshift);
   fprintf(fp, "    [-preemph]          pre-emphasis coef.                    (%.2f)\n", jconf->am_root->analysis.para_default.preEmph);
@@ -359,6 +361,15 @@ j_output_argument_help(FILE *fp)
   fprintf(fp, "    [-walign]           optionally output word alignments\n");
   fprintf(fp, "    [-palign]           optionally output phoneme alignments\n");
   fprintf(fp, "    [-salign]           optionally output state alignments\n");
+
+#ifdef USE_MBR
+  fprintf(fp, "\n Minimum Bayes Risk Decoding:\n");
+  fprintf(fp, "    [-mbr]              enable rescoring sentence on MBR(WER)\n");
+  fprintf(fp, "    [-mbr_wwer]         enable rescoring sentence on MBR(WWER)\n");
+  fprintf(fp, "    [-nombr]            disable rescoring sentence on MBR\n");
+  fprintf(fp, "    [-mbr_weight float float] score and loss func. weight on MBR (%.1f %.1f)\n", jconf->search_root->mbr.score_weight, jconf->search_root->mbr.loss_weight);
+#endif
+
 #ifdef CONFIDENCE_MEASURE
   fprintf(fp, "\n Confidence Score:\n");
 #ifdef CM_MULTIPLE_ALPHA
