@@ -111,13 +111,13 @@
  * @author Akinobu Lee
  * @date   Tue Aug 23 11:44:14 2005
  *
- * $Revision: 1.9 $
+ * $Revision: 1.11 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -1161,6 +1161,12 @@ RealTimeParam(Recog *recog)
   /* loop until all data has been flushed */
   while (1) {
 
+    /* check frame overflow */
+    for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
+      if (! mfcc->valid) continue;
+      if (mfcc->f >= r->maxframelen) mfcc->valid = FALSE;
+    }
+
     /* if all mfcc became invalid, exit loop here */
     ok_p = FALSE;
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
@@ -1321,7 +1327,6 @@ RealTimeParam(Recog *recog)
     for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
       if (! mfcc->valid) continue;
       mfcc->f++;
-      if (mfcc->f > r->maxframelen) mfcc->valid = FALSE;
     }
   }
 
